==> k4de-0.3.0.tgz: k4de-0.3.0/src/3d/textures/normalentry.h <==
/******************************************************************************
**                                                                           **
**    k4de - 3d-editor for the K Desktop Enviroment                          **
**                                                                           **
**    Copyright (C) 1999  Tobias Wollgam (tobias.wollgam@gmx.de)             **
**    Copyright (C) 1999  Markus Weber (mweber@gmx.de)                       **
**                                                                           **
**    This program is free software; you can redistribute it and/or modify   **
**    it under the terms of the GNU General Public License as published by   **
**    the Free Software Foundation; either version 2 of the License, or      **
**    (at your option) any later version.                                    **
**                                                                           **
**    This program is distributed in the hope that it will be useful,        **
**    but WITHOUT ANY WARRANTY; without even the implied warranty of         **
**    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          **
**    GNU General Public License for more details.                           **
**                                                                           **
**    You should have received a copy of the GNU General Public License      **
**    along with this program; if not, write to the Free Software            **
**    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.              **
**                                                                           **
******************************************************************************/
/*
** normalentry.h
*/
#ifndef __NORMALENTRY_H__
#define __NORMALENTRY_H__

#include <misc.h>
#include <list.h>
#include "normal.h"
#include <stdio.h>


class normal;

class normalEntry:public virtual chunk
{
protected:


public:
	normalEntry(double, normal* );
	~normalEntry();

	double	range;
	normal *no;

	void setNormalRange(double);
	double getNormalRange();

	int	save(media*);
	int	load(media*,int);

	int	exportPOV(FILE*,int,int,int);
};

#endif

==> k4de-0.4.0.tgz: k4de-0.4.0/src/3d/textures/normalentry.h <==
/******************************************************************************
**                                                                           **
**    k4de - 3d-editor for the K Desktop Enviroment                          **
**                                                                           **
**    Copyright (C) 1999  Tobias Wollgam (tobias.wollgam@gmx.de)             **
**    Copyright (C) 1999  Markus Weber (mweber@gmx.de)                       **
**                                                                           **
**    This program is free software; you can redistribute it and/or modify   **
**    it under the terms of the GNU General Public License as published by   **
**    the Free Software Foundation; either version 2 of the License, or      **
**    (at your option) any later version.                                    **
**                                                                           **
**    This program is distributed in the hope that it will be useful,        **
**    but WITHOUT ANY WARRANTY; without even the implied warranty of         **
**    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          **
**    GNU General Public License for more details.                           **
**                                                                           **
**    You should have received a copy of the GNU General Public License      **
**    along with this program; if not, write to the Free Software            **
**    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.              **
**                                                                           **
******************************************************************************/
/*
** normalentry.h
*/
#ifndef __NORMALENTRY_H__
#define __NORMALENTRY_H__

#include <misc.h>
#include <list.h>
#include "normal.h"
#include <stdio.h>
#include "texturebase.h"
#include "transformations.h"
#include "normalmap.h"
#include "slopemap.h"
#include "bumpmap.h"
#include "normallist.h"
#include "turbulence.h"

class normal;

class normalEntry:public textureBase
{
protected:
	patternmodifier	modifier;
	double	range;
	Transformations transform;
	Turbulence	turbulence;
	bool		usePattern;

	void updateInfo();

public:
	normalEntry(textureBase *p=NULL );
	~normalEntry();

	patternmodifier 	*getMapModifier();

        void	setUsePattern(bool);
	bool	getUsePattern();

	void	addElement(textureBase *,textureBase *a=NULL);
	void	setActive(bool a,textureBase *tb);

	bool	isExportable();

	void setRange(double);
	double getRange();

	void	add(textureBase *);

	bool	isEqual(textureBase *);

	int	save(media*);
	int	load(media*,int);
	int	exportPOV(FILE*,int,int,int,bool);
};

#endif
